@@ -8,7 +8,7 @@ https://data.eastmoney.com/cjsj/foreign_8_0.html
 import pandas as pd
 import requests
 
-import PPshare.economic.demjson as demjson
+from akshare.utils import demjson
 
 
 def macro_china_hk_cpi() -> pd.DataFrame:
